#Set-up - the working directory 
#(so R knows where to look for data and save files)
setwd("Wherever your data files are")

#Load the necessary packages  ----
#(so R can access the any additional functions needed for the next steps)
library(tidyverse)
library(readxl)

#Import, Explore + Clean the data ---
#(to get the data in R an make sure the data is error free for analysis)
titanic_data<-read_excel("titanic3.xls")
#quickly view the name and type of each column
str(titanic_data)
#view summary statistics on the data 
summary(titanic_data)

#clean the data: 
#make the survived column a 'logical' class 
titanic_data$survived_logical<-as.logical(titanic_data$survived)
#check if it worked 
table(titanic_data$survived,titanic_data$survived_logical)

#Explain - analyse, understand and visualize  ----
#(to answer the questions we want to pose)

#how many of each class were onboard? 
passengers_by_class<-table(titanic_data$pclass)
plot(passengers_by_class)

#Were those with higher class tickets more likely to survive? 
passengers_by_class_and_survival<-table(titanic_data$pclass,titanic_data$survived_logical)
plot(passengers_by_class_and_survival)

#How about for women by class? 
passengers_by_class_and_survival_vs_gender<-table(titanic_data$survived_logical,titanic_data$sex,titanic_data$pclass)
plot(passengers_by_class_and_survival_vs_gender)

#Save the results ----
#(to present to others and add to other documents)
write.csv(passengers_by_class_and_survival_vs_gender,"passenger survival by gender and class.csv")
